slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSPEPSetCoefficients

Sets the polynomial basis coefficients for a DSPEP.

### Synopsis

    #include "slepcds.h"
    PetscErrorCode DSPEPSetCoefficients(DS ds,PetscReal *pbc)

Logically Collective on ds

### Input Parameters

| ds | - the direct solver context
| pbc | - the polynomial basis coefficients

### Notes

This function is required only in the case of a polynomial specified in a non-monomial basis, to provide the coefficients that will be used during the linearization, multiplying the identity blocks on the three main diagonal blocks. Depending on the polynomial basis (Chebyshev, Legendre, ...) the coefficients must be different.

There must be a total of 3*(d+1) coefficients, where d is the degree of the polynomial. The coefficients are arranged in three groups, alpha, beta, and gamma, according to the definition of the three-term recurrence. In the case of the monomial basis, alpha=1 and beta=gamma=0, in which case it is not necessary to invoke this function.

### See Also

DSPEPGetCoefficients(), DSPEPSetDegree()

### Level

advanced

### Location

src/sys/classes/ds/impls/pep/dspep.c
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages